from django.conf.urls import include, url
from django.conf import settings

from django.views.generic import RedirectView
from django.core.urlresolvers import reverse_lazy

from django.contrib import admin

from . import search
from . import views

urlpatterns = [
    url(r'^$', views.home, name='home'),
    url(r'^onair.json$', views.onair, name='onair'),
    url(r'^programme/$', views.program, name='program'),
    url(r'^programme/(?P<year>\d{4})/(?P<week>\d+)/$', views.program, name='program_week'),
    url(r'^grille$', views.grid, name='grid'),
    url(r'^emissions/$', RedirectView.as_view(pattern_name='home'), name='emissions'),
    url(r'^emissions/(?P<slug>[\w,-]+)/episodes/$', views.emissionEpisodes, name='emissionEpisodes'),
    url(r'^emissions/(?P<slug>[\w,-]+)/podcasts.rss', views.emission_podcasts_feed, name='emission-podcasts'),
    url(r'^emissions/(?P<slug>[\w,-]+)/chat/$', views.chat, name='emission-chat'),
    url(r'^emissions/(?P<emission_slug>[\w,-]+)/(?P<slug>[\w,-]+)/$', views.episode, name='episode-view'),
    url(r'^emissions/(?P<emission_slug>[\w,-]+)/(?P<episode_slug>[\w,-]+)/embed/(?P<pk>\d+)/$',
        views.soundfile_embed, name='soundfile-embed-view'),
    url(r'^emissions/(?P<emission_slug>[\w,-]+)/(?P<episode_slug>[\w,-]+)/dlg-embed/(?P<pk>\d+)/$',
        views.soundfile_dlg_embed, name='soundfile-dialog-embed-view'),
    url(r'^emissions/(?P<slug>[\w,-]+)/playlist/(?P<year>[0-9]{4})-(?P<month>[-\w]+)-(?P<day>[0-9]+)/$',
        views.nonstop_playlist, name='nonstop-playlist'),
    url(r'^emissions/(?P<slug>[\w,-]+)/$', views.emission, name='emission-view'),
    url(r'^emissions/archives$', views.emissionsArchives, name='emissionsArchives'),
    url(r'^sons/$', views.listen, name='listen'),
    url(r'^sons/archives/$', search.listenArchives, name='listenArchives'),

    url(r'^party', views.party, name='party'),

    url(r'^recherche/', search.view, name='search'),

    url(r'^podcasts.rss', views.podcasts_feed, name='podcasts-feed'),

    url(r'^newsletter/', include('newsletter.urls')),

    url(r'^archives/$', views.archives, name='espe-archives'),

    url(r'^admin/', include(admin.site.urls)),
    url(r'^admin/doc/', include('django.contrib.admindocs.urls')),
]

from django.contrib.staticfiles.urls import staticfiles_urlpatterns
urlpatterns += staticfiles_urlpatterns()

from django.conf.urls.static import static
urlpatterns += static(settings.MEDIA_URL, document_root=settings.MEDIA_ROOT)

urlpatterns.append(url(r'', include('combo.public.urls')))

try:
    from local_urls import *
except ImportError as e:
    pass
